@@ -138,34 +138,6 @@ class EiamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DecribePublicKey(self, request):
-        """获取JWT公钥信息
-
-        :param request: Request instance for DecribePublicKey.
-        :type request: :class:`tencentcloud.eiam.v20210420.models.DecribePublicKeyRequest`
-        :rtype: :class:`tencentcloud.eiam.v20210420.models.DecribePublicKeyResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DecribePublicKey", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DecribePublicKeyResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DeleteOrgNode(self, request):
         """删除一个机构节点
 
@@ -306,6 +278,62 @@ class EiamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeOrgResourcesAuthorization(self, request):
+        """查询指定机构下的资源授权列表
+
+        :param request: Request instance for DescribeOrgResourcesAuthorization.
+        :type request: :class:`tencentcloud.eiam.v20210420.models.DescribeOrgResourcesAuthorizationRequest`
+        :rtype: :class:`tencentcloud.eiam.v20210420.models.DescribeOrgResourcesAuthorizationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeOrgResourcesAuthorization", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeOrgResourcesAuthorizationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribePublicKey(self, request):
+        """获取JWT公钥信息。
+
+        :param request: Request instance for DescribePublicKey.
+        :type request: :class:`tencentcloud.eiam.v20210420.models.DescribePublicKeyRequest`
+        :rtype: :class:`tencentcloud.eiam.v20210420.models.DescribePublicKeyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePublicKey", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePublicKeyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeUserGroup(self, request):
         """获取用户组信息
 
@@ -334,6 +362,34 @@ class EiamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeUserGroupResourcesAuthorization(self, request):
+        """查询指定用户组下的资源授权列表
+
+        :param request: Request instance for DescribeUserGroupResourcesAuthorization.
+        :type request: :class:`tencentcloud.eiam.v20210420.models.DescribeUserGroupResourcesAuthorizationRequest`
+        :rtype: :class:`tencentcloud.eiam.v20210420.models.DescribeUserGroupResourcesAuthorizationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeUserGroupResourcesAuthorization", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeUserGroupResourcesAuthorizationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeUserInfo(self, request):
         """通过用户名或用户 id 搜索用户
 
@@ -362,6 +418,90 @@ class EiamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeUserResourcesAuthorization(self, request):
+        """查询指定用户下的资源授权列表
+
+        :param request: Request instance for DescribeUserResourcesAuthorization.
+        :type request: :class:`tencentcloud.eiam.v20210420.models.DescribeUserResourcesAuthorizationRequest`
+        :rtype: :class:`tencentcloud.eiam.v20210420.models.DescribeUserResourcesAuthorizationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeUserResourcesAuthorization", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeUserResourcesAuthorizationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ListApplicationAuthorizations(self, request):
+        """应用授权关系列表（含搜索条件匹配）。
+
+        :param request: Request instance for ListApplicationAuthorizations.
+        :type request: :class:`tencentcloud.eiam.v20210420.models.ListApplicationAuthorizationsRequest`
+        :rtype: :class:`tencentcloud.eiam.v20210420.models.ListApplicationAuthorizationsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListApplicationAuthorizations", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListApplicationAuthorizationsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ListApplications(self, request):
+        """获取应用列表信息。
+
+        :param request: Request instance for ListApplications.
+        :type request: :class:`tencentcloud.eiam.v20210420.models.ListApplicationsRequest`
+        :rtype: :class:`tencentcloud.eiam.v20210420.models.ListApplicationsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListApplications", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListApplicationsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ListAuthorizedApplicationsToOrgNode(self, request):
         """通过机构节点ID获得被授权访问的应用列表。
 
@@ -446,6 +586,34 @@ class EiamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ListUserGroups(self, request):
+        """获取用户组列表信息（包含查询条件）。
+
+        :param request: Request instance for ListUserGroups.
+        :type request: :class:`tencentcloud.eiam.v20210420.models.ListUserGroupsRequest`
+        :rtype: :class:`tencentcloud.eiam.v20210420.models.ListUserGroupsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListUserGroups", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListUserGroupsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ListUserGroupsOfUser(self, request):
         """获取用户所在的用户组列表
 
@@ -474,6 +642,34 @@ class EiamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ListUsers(self, request):
+        """获取用户列表信息。
+
+        :param request: Request instance for ListUsers.
+        :type request: :class:`tencentcloud.eiam.v20210420.models.ListUsersRequest`
+        :rtype: :class:`tencentcloud.eiam.v20210420.models.ListUsersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListUsers", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListUsersResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ListUsersInOrgNode(self, request):
         """根据机构节点ID读取节点下用户
 
@@ -530,6 +726,34 @@ class EiamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyApplication(self, request):
+        """更新一个应用的信息
+
+        :param request: Request instance for ModifyApplication.
+        :type request: :class:`tencentcloud.eiam.v20210420.models.ModifyApplicationRequest`
+        :rtype: :class:`tencentcloud.eiam.v20210420.models.ModifyApplicationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyApplication", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyApplicationResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyUserInfo(self, request):
         """通过用户名或用户 id 冻结用户
 
