@@ -17,6 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# token校验失败。
+AUTHFAILURE_TOKENFAILURE = 'AuthFailure.TokenFailure'
+
 # DryRun 操作，代表请求将会是成功的，只是多传了 DryRun 参数。
 DRYRUNOPERATION = 'DryRunOperation'
 
@@ -116,6 +119,12 @@ INVALIDPARAMETER_RECORDUNSUPPORTWEIGHT = 'InvalidParameter.RecordUnsupportWeight
 # VPC已绑定其它解析域。
 INVALIDPARAMETER_VPCBINDED = 'InvalidParameter.VpcBinded'
 
+# 当前VPC已关联相同主域名。
+INVALIDPARAMETER_VPCBINDEDMAINDOMAIN = 'InvalidParameter.VpcBindedMainDomain'
+
+# VPC关联反解析域超过限制。
+INVALIDPARAMETER_VPCPTRZONEBINDEXCEED = 'InvalidParameter.VpcPtrZoneBindExceed'
+
 # 解析域不存在。
 INVALIDPARAMETER_ZONENOTEXISTS = 'InvalidParameter.ZoneNotExists'
 
@@ -155,6 +164,9 @@ RESOURCESSOLDOUT = 'ResourcesSoldOut'
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 角色未授权。
+UNAUTHORIZEDOPERATION_ROLEUNAUTHORIZED = 'UnauthorizedOperation.RoleUnAuthorized'
+
 # 未实名账号。
 UNAUTHORIZEDOPERATION_UNAUTHORIZEDACCOUNT = 'UnauthorizedOperation.UnauthorizedAccount'
 
@@ -163,3 +175,6 @@ UNKNOWNPARAMETER = 'UnknownParameter'
 
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
+# 账号未绑定。
+UNSUPPORTEDOPERATION_ACCOUNTNOTBOUND = 'UnsupportedOperation.AccountNotBound'
